@@ -3,8 +3,8 @@ extern crate clap;
 
 use gnuplot::{Figure, Color};
 use clap::{Arg, App};
-use dsp::node::SourceNode;
-use dsp::generator::*;
+use dsp::runtime::node::SourceNode;
+use dsp::node::generator::*;
 
 
 const SIGNAL_LENGTH: usize = 1_000;
@@ -59,7 +59,7 @@ fn main() {
     let params = parse_params();
     let mut generator = create_generator(&params);
     let mut buffer = vec![0.0; SIGNAL_LENGTH];
-    generator.write_buffer(&mut buffer);
+    let _ = generator.write_buffer(&mut buffer);
 
     // Plot signal
     let idx: Vec<usize> = (0..buffer.len()).collect();
